@@ -33,7 +33,10 @@ class Stock:
             if 'dividends' in self._raw_data['chart']['result'][0]['events']:
                 self._div_data = list(self._raw_data['chart']['result'][0]['events']['dividends'].values())
                 self.div_df = pd.DataFrame.from_records(self._div_data)
+                self.div_df = self.div_df.rename(columns={'amount': 'div_amount'})
                 self.div_df['date'] = pd.to_datetime(self.div_df['date'], unit='s').dt.date
+                self.div_df['div_growth'] = self.div_df['div_amount'].diff()
+                self.div_df = self.div_df[['date', 'div_amount', 'div_growth']]
 
         self._hist_data = self._raw_data['chart']['result'][0]['indicators']['quote'][0]
         self.hist_df = pd.DataFrame.from_dict(self._hist_data)
